aboutsummaryrefslogtreecommitdiffstats
path: root/spec
diff options
context:
space:
mode:
authorUlrich-Matthias Schäfer <ulima.ums@googlemail.com>2023-04-05 13:42:41 +0200
committerGitHub <noreply@github.com>2023-04-05 13:42:41 +0200
commit770ca58d58bcb48a52367e9a340ab06c0053f1d5 (patch)
tree6d60e71adf69fdb7b59534d4a2d4137d5d124a88 /spec
parentd8ce1aec598e36457c0bb7e923cf5642420ceb86 (diff)
parentd3630aa69816e78a274e5b18dd1e027aa8a7e6ec (diff)
downloadsvg.js-770ca58d58bcb48a52367e9a340ab06c0053f1d5.tar.gz
svg.js-770ca58d58bcb48a52367e9a340ab06c0053f1d5.zip
Merge pull request #1294 from timgates42/bugfix_typos
docs: Fix a few typos
Diffstat (limited to 'spec')
-rw-r--r--spec/spec/animation/Runner.js22
1 files changed, 11 insertions, 11 deletions
diff --git a/spec/spec/animation/Runner.js b/spec/spec/animation/Runner.js
index b9a6342..a56ac37 100644
--- a/spec/spec/animation/Runner.js
+++ b/spec/spec/animation/Runner.js
@@ -915,7 +915,7 @@ describe('Runner.js', () => {
it('throws away the morpher if it wasnt initialized yet and returns false', () => {
const rect = new Rect().move(0, 0)
const runner = rect.animate().move(10, 10)
// In that case tryRetarget is not successfull
expect(runner._tryRetarget('x', 20)).toBe(false)
})
@@ -923,7 +923,7 @@ describe('Runner.js', () => {
const rect = new Rect().move(0, 0)
const runner = rect.animate().move(10, 10)
jasmine.RequestAnimationFrame.tick(16)
// In that case tryRetarget is not successfull
expect(runner._tryRetarget('foo', 20)).toBe(false)
})
@@ -931,11 +931,11 @@ describe('Runner.js', () => {
const rect = new Rect()
const runner = rect.animate(new Controller(() => 0)).transform({ translate: [ 10, 10 ] })
jasmine.RequestAnimationFrame.tick(16)
// In that case tryRetarget is not successfull
expect(runner._tryRetarget('transform', { translate: [ 20, 20 ] })).toBe(true)
})
- it('starts the timeline if retarget was successfull', () => {
+ it('starts the timeline if retarget was successful', () => {
const timeline = new Timeline()
const rect = new Rect().move(0, 0).timeline(timeline)
const runner = rect.animate().move(10, 10)
@@ -1334,7 +1334,7 @@ describe('Runner.js', () => {
runner.transform({ translate: [ 10, 20 ], scale: 2, rotate: 90 })
runner.step(50)
// transform sets an immediate callback to apply all merged transforms
- // when every runner had the chance to add its bit of tranforms
+ // when every runner had the chance to add its bit of transforms
jasmine.RequestAnimationFrame.tick(1)
expect(element.matrix().decompose()).toEqual(objectContaining({
translateX: 5,
@@ -1385,7 +1385,7 @@ describe('Runner.js', () => {
runner.translate(10, 20).scale(2).rotate(45)
runner.step(50)
// transform sets an immediate callback to apply all merged transforms
- // when every runner had the chance to add its bit of tranforms
+ // when every runner had the chance to add its bit of transforms
jasmine.RequestAnimationFrame.tick(1)
// The origin is transformed with every
@@ -1406,7 +1406,7 @@ describe('Runner.js', () => {
runner2.step(50)
runner3.step(50)
// transform sets an immediate callback to apply all merged transforms
- // when every runner had the chance to add its bit of tranforms
+ // when every runner had the chance to add its bit of transforms
jasmine.RequestAnimationFrame.tick(1)
// The origin is transformed with every
@@ -1427,7 +1427,7 @@ describe('Runner.js', () => {
runner2.step(50)
runner3.step(50)
// transform sets an immediate callback to apply all merged transforms
- // when every runner had the chance to add its bit of tranforms
+ // when every runner had the chance to add its bit of transforms
jasmine.RequestAnimationFrame.tick(1)
expect(runner1._queue.length).toBe(0)
@@ -1444,7 +1444,7 @@ describe('Runner.js', () => {
runner.transform(new Matrix({ rotate: 90 }))
runner.step(50)
// transform sets an immediate callback to apply all merged transforms
- // when every runner had the chance to add its bit of tranforms
+ // when every runner had the chance to add its bit of transforms
jasmine.RequestAnimationFrame.tick(1)
// The origin is transformed with every
@@ -1459,7 +1459,7 @@ describe('Runner.js', () => {
runner.transform(Object.assign({ affine: true }, new Matrix({ rotate: 90 })))
runner.step(50)
// transform sets an immediate callback to apply all merged transforms
- // when every runner had the chance to add its bit of tranforms
+ // when every runner had the chance to add its bit of transforms
jasmine.RequestAnimationFrame.tick(1)
// The origin is transformed with every
@@ -1474,7 +1474,7 @@ describe('Runner.js', () => {
runner.transform(new Matrix({ rotate: 90 }), true, true)
runner.step(50)
// transform sets an immediate callback to apply all merged transforms
- // when every runner had the chance to add its bit of tranforms
+ // when every runner had the chance to add its bit of transforms
jasmine.RequestAnimationFrame.tick(1)
// The origin is transformed with every
@@ -915,7 +915,7 @@ describe('Runner.js', () => {
const rect = new Rect().move(0, 0)
const runner = rect.animate().move(10, 10)
- // In that case tryRetarget is not successfull
+ // In that case tryRetarget is not successful
expect(runner._tryRetarget('x', 20)).toBe(false)
})
@@ -923,7 +923,7 @@ describe('Runner.js', () => {
const runner = rect.animate().move(10, 10)
jasmine.RequestAnimationFrame.tick(16)
- // In that case tryRetarget is not successfull
+ // In that case tryRetarget is not successful
expect(runner._tryRetarget('foo', 20)).toBe(false)
})
@@ -931,11 +931,11 @@ describe('Runner.js', () => {
const runner = rect.animate(new Controller(() => 0)).transform({ translate: [ 10, 10 ] })
jasmine.RequestAnimationFrame.tick(16)
- // In that case tryRetarget is not successfull
+ // In that case tryRetarget is not successful
expect(runner._tryRetarget('transform', { translate: [ 20, 20 ] })).toBe(true)
})